mir.anidb README
================

.. image:: https://circleci.com/gh/darkfeline/mir.anidb.svg?style=shield
   :target: https://circleci.com/gh/darkfeline/mir.anidb
   :alt: CircleCI
.. image:: https://codecov.io/gh/darkfeline/mir.anidb/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/darkfeline/mir.anidb
   :alt: Codecov
.. image:: https://badge.fury.io/py/mir.anidb.svg
   :target: https://badge.fury.io/py/mir.anidb
   :alt: PyPI Release

AniDB API.
